# ========== 核心支持库命令 ==========
from pyefun.核心支持库.算数运算 import *
from pyefun.核心支持库.数组操作 import *
from pyefun.核心支持库.编码转换 import *
from pyefun.核心支持库.磁盘操作 import *
from pyefun.核心支持库.公用函数 import *
from pyefun.核心支持库.文本操作 import *
from pyefun.核心支持库.系统处理 import *
from pyefun.核心支持库.日期时间操作 import *
from pyefun.核心支持库.类型转换 import *
from pyefun.核心支持库.时钟 import *
# ========== 核心支持库命令 ==========

# ========== 核心易函数支持库 ==========
from pyefun.核心易函数支持库.实用函数 import *
from pyefun.核心易函数支持库.文本操作实用函数 import *
from pyefun.核心易函数支持库.正则表达式 import *
from pyefun.核心易函数支持库.正则表达式实用函数 import *
from pyefun.核心易函数支持库.网络请求 import *  # 易函数易用的请求模块
from pyefun.核心易函数支持库.时间统计 import *
from pyefun.核心易函数支持库.线程操作 import *
from pyefun.核心易函数支持库.进程池 import *
from pyefun.核心易函数支持库.json函数 import *
from pyefun.核心易函数支持库.环境变量 import *
from pyefun.核心易函数支持库.配置项 import *
from pyefun.核心易函数支持库.网络实用函数 import *
# ========== 核心易函数支持库 ==========


# ========== 模块 ==========
# from pyefun.模块.javascript引擎 import *  # 执行js脚本
# from pyefun.模块.二维码 import *  # 二维码解析
# from pyefun.模块.剪切板操作 import *  # 剪切板操作
# from pyefun.模块.协程池 import *  # 原生协程池
# from pyefun.模块.协程池Gevent import *  # Gevent协程池
# from pyefun.模块.窗口操作 import *  # 窗口操作
# from pyefun.模块.进度显示 import *  # 进度显示
# from pyefun.模块.缓存工具 import *  # 缓存工具
# from pyefun.模块.邮件 import *  # 邮件
# from pyefun.模块.定时任务 import *  # 定时任务
# from pyefun.模块.winapi import *  # window api
# from pyefun.模块.通用实用函数 import *  # ubelt 封装的实用函数
# ========== 模块 ==========

# ========== 编码解码 ==========
# from pyefun.编码解码.gzip解压缩 import * # gzip 解压缩
# from pyefun.编码解码.zlib解压缩 import * # zlib 解压缩
# from pyefun.编码解码.zip解压缩 import * # zip 解压缩
# from pyefun.编码解码.binary编码解码 import * # 二进制 编码解码
# from pyefun.编码解码.base64编码解码 import * # base64 编码解码
# from pyefun.编码解码.url编码解码 import * # URL 编码解码
# ========== 编码解码 ==========

# ========== 数据库 ==========
# from pyefun.数据库.redis工具类 import * # redis
# from pyefun.数据库.mysql数据库 import * # mysql数据库
# from pyefun.数据库.mongo数据库 import * # mongo数据库
# from pyefun.数据库.peeweeUtil import * # peeweeUtil
# ========== 数据库 ==========

# ========== excel操作 ==========
# from pyefun.excel.excel_xlwr import * # excel操作模块 选其中一个使用即可
# from pyefun.excel.excel_openpyxl import * # excel操作模块 选其中一个使用即可
# ========== excel操作 ==========

# ========== 浏览器自动化操作 ==========
# from pyefun.seleniumUtil import * # 浏览器自动化测试
# ========== 浏览器自动化操作 ==========

# ========== 阿里云SDK ==========
# from pyefun.阿里云SDK.fc.fc import *  # 阿里云函数计算操作
# from pyefun.阿里云SDK.oss.oss import *  # 阿里云oss操作sdk
# ========== 阿里云SDK ==========

# ========== 人工智能 ==========
# from pyefun.人工智能.ONNX分类模型推理 import *  # ONNX分类模型推理
# from pyefun.人工智能.通用文字识别 import *  # 提供通用的中文文字识别功能
# ========== 人工智能 ==========

# ========== 图像处理 ==========
# from pyefun.图像处理 import *  # 图片处理 cv2 以及 pil 的工具类
# from pyefun.图像处理.图像处理 import * # opencv 工具类
# from pyefun.图像处理.图像处理PIL import * # pil 工具类
# ========== 图像处理 ==========


__version__ = '1.2.2'
