
import wx
from .wxControl import *

组件名称 = "选择夹"
组件创建代码 = """wx.选择夹(self.容器, size=({宽度}, {高度}), pos=({左边}, {顶边}), style=wx.NB_FIXEDWIDTH)"""
界面设计器使用占位符创建 = True

class 选择夹(wx.Notebook, 公用方法):
    pass
